Clipped

Struct Clipped 

pub struct Clipped<'p, P>
where P: Painter + ?Sized,
{ /* private fields */ }
A painter with a narrowed clip, which it restores when dropped.

Derefs to the painter, so it is used exactly as one.