Canvas wearing the painting contract.
Structs
- Clip
Token - Proof that a clip was narrowed, and the only way to widen one back.
- Clipped
- A painter with a narrowed clip, which it restores when dropped.
- Pen
- The pen widgets draw with: a
&mut dyn Painterwearing the ergonomics the trait cannot have.
Traits
- Painter
- A clipped drawing target.
- Painter
Ext - The part of the painting API that cannot be object-safe.